@@ -138,7 +138,7 @@ def _format(response):
         'card': {'id': response['customer_token']} if 'customer_token' in response else _format_card(response),
         'payment_day': date,
         'statement_descriptor': response['establishment_name'],
-        'payment_method_id': str(response['payment_method_id']),
+        'payment_method_id': response['payment_method_id'],
         'payment_method': response['payment_method'],
         'installments': response['installments'],
     }
@@ -184,7 +184,7 @@ class Payment(MuviBase):
             'site_id': site_id,
             'site_transaction_id': str(site_transaction_id),
             'token': payment_data['token'],
-            'payment_method_id': int(payment_data['payment_method_id']) if 'payment_method_id' in payment_data else 1,
+            'payment_method_id': payment_data['payment_method_id'],
             'bin': payment_data['bin'],     # primeros 6 digitos de la tarjeta
             'currency': 'ARS',
             'payment_type': 'single',
@@ -196,6 +196,7 @@ class Payment(MuviBase):
         if 'application_fee' in payment_data and self.marketplace:
             application_fee = round(payment_data['application_fee'], 2) * 100
             body['payment_type'] = 'distributed'
+            del body['site_id']
             body['sub_payments'] = [
                 {
                     'site_id': self.site_id_cadena_sin_cvv,
